import QtQuick 1.0

Rectangle {
    property int toolBarWidth
    property int toolBarHeight
    property string bgImage
    property variant toolbarModel
    property int defaultCurrentIndex: 0
    property real bgImageOpacity: 1.0
    property string imageBack:"../pics/back1.png"
    property string imageBackPress: "../pics/back2click.png"
    property bool backPressed: false
    property bool hasBackButton: false
    signal itemClicked(int id)
    signal clickOnBack()

    width: toolBarWidth
    height: toolBarHeight
    function setCurrentIndex(index)
    {
        listView.currentIndex = index;
    }

    Item {
        width: parent.width
        height: parent.height
        anchors{bottom:parent.bottom; horizontalCenter:parent.horizontalCenter}

        Image {
            id: background
            width: parent.width
            height: parent.height
            anchors{ bottom:parent.bottom; horizontalCenter:parent.horizontalCenter}
            source: bgImage
            smooth: true
            fillMode: Image.Stretch
            opacity: bgImageOpacity
        }
    }

    Component {
        id: recipeDelegate

        Item {
            id: recipe
            anchors{ bottom:parent.bottom}
            width:{
                if(hasBackButton == true && listView.count>2) return toolBarWidth/(listView.count+1);
                if(hasBackButton == true && listView.count<3) return toolBarWidth/4;
                if(hasBackButton == false && listView.count>3)return toolBarWidth/listView.count;
                else return toolBarWidth/4;
            }
            height:background.height

            MouseArea {
                id:mouse
                anchors.fill: parent
                onPressed:{
                listView.currentIndex=index
                }
                onReleased: {
                    itemClicked(index);
                }

            }

            Rectangle {
                id:imageContainer
                x:0
                y:0
                width: parent.width
                height: parent.height
                color: "transparent"
                Image {
                    id: recipeImage
                    source: {
                        if(listView.currentIndex != index) return itemImg;
                        else return itemHighlightImg;
                    }
                    anchors.centerIn:parent
                    fillMode:Image.PreserveAspectFit
                    smooth:true
                }
            }
        }
    }
    Rectangle{
        id:backButton
        height: toolBarHeight
        width:{
            if(hasBackButton == true && listView.count>2) return toolBarWidth/(listView.count+1);
            if(hasBackButton == true && listView.count<3) return toolBarWidth/4;
            else return 0;
        }
        anchors.left: parent.left
        anchors.top:parent.top
        color: "transparent"
        visible: hasBackButton
        Image {
            anchors.centerIn: parent
            source: {
                if(backPressed) return imageBackPress
                else return imageBack
            }
        }
        MouseArea{
            anchors.fill: parent
            onPressed: {
                backPressed = true
            }
            onReleased: {
                backPressed = false
                clickOnBack();
            }
            onExited: {
                backPressed = false
            }
        }
    }
    Rectangle{
        id:forList
        height: toolBarHeight
        width: toolBarWidth - backButton.width
        anchors.left: backButton.right
        anchors.top:parent.top
        color: "transparent"
        ListView {
            id: listView
            orientation: ListView.Horizontal
            anchors.fill: forList
            model: toolbarModel
            delegate: recipeDelegate
            interactive:false
            focus:true
            currentIndex:defaultCurrentIndex

            highlight:
                Rectangle {
                    id: high
                    width:(hasBackButton)? toolBarWidth/(listView.count+1):toolBarWidth/listView.count
                    height:background.height
                    x: listView.currentItem.x
                    y: listView.currentItem.y

                    radius: 5
                    color: "white"
                    opacity: 0.5
                }
            highlightFollowsCurrentItem:false
        }
    }
}
