import QtQuick 1.0

Rectangle {
    property int toolBarWidth
    property int toolBarHeight
    property string bgImage
    property variant toolbarModel
    property real bgImageOpacity: 1.0

    signal itemClicked(int id)

    width: toolBarWidth
    height: toolBarHeight
    function setCurrentIndex(index)
    {
        listView.currentIndex = index;
    }

    Item {
        width: parent.width
        height: parent.height
        anchors{bottom:parent.bottom; horizontalCenter:parent.horizontalCenter}

        Image {
            id: background
            width: parent.width
            height: parent.height
            anchors{ bottom:parent.bottom; horizontalCenter:parent.horizontalCenter}
            source: bgImage
            smooth: true
            fillMode: Image.Stretch
            opacity: bgImageOpacity
        }
    }

    Component {
        id: recipeDelegate

        Item {
            id: recipe
            anchors{ bottom:parent.bottom}
            width:(listView.count <6)? toolBarWidth/listView.count : toolBarWidth/5
            height:background.height

            MouseArea {
                id:mouse
                anchors.fill: parent
                onClicked: {
                    itemClicked(index);
                    listView.currentIndex=index
                    }
            }

            Rectangle {
                id:imageContainer
                x:0
                y:0
                width: parent.width
                height: parent.height-textContainer.height
                color: "transparent"
                Image {
                    id: recipeImage
                    source:
                    {
                        if(grayFlag)
                        {
                            return grayImg;
                        }
                        else
                        {
                            return itemImg;
                        }
                    }
                    anchors.centerIn:parent
                    fillMode:Image.PreserveAspectFit
                    smooth:true
                }
            }

            Image {
                id: highlightImg
                source: itemHighlightImg
                anchors.centerIn:imageContainer
                fillMode: Image.PreserveAspectFit
                smooth:true
                visible: (!grayFlag)&&mouse.pressed
            }

            Rectangle
            {
                id:textContainer
                width: parent.width
                height: parent.height/3
                anchors.bottom: parent.bottom
                color: "transparent"
                Text {
                    anchors.centerIn: parent
                    color: "white"
                    text: buttonText
                    font.pixelSize: 25
                }
            }

            Rectangle {
                id: high
                width:(listView.count <6)? toolBarWidth/listView.count : toolBarWidth/5
                height:background.height
                visible: (!grayFlag)&&mouse.pressed
                radius: 5
                color: "white"
                opacity: 0.5
            }
        }
    }

    ListView {
        id: listView
        orientation: ListView.Horizontal
        anchors.fill: parent
        model: toolbarModel
        delegate: recipeDelegate
        interactive:(count < 6)? false:true
    }
}
